@@ -1,4 +1,4 @@
-from collections import Mapping, Iterable
+from collections.abc import Mapping, Iterable
 import ds_format as ds
 from .op import gen_dims
 
